import {
  Modal, ModalService, Button,
  Grid, Select,
  IButtonEvent,
} from '@zeedhi/common';
import {
  Metadata, IDictionary, IEventParam,
  Loader, Http, dayjs as moment,
} from '@zeedhi/core';
import { Cardapio } from '../../../components/cardapio/common/Cardapio';

export class Pme00611AnaliseCusto {
  private modalAnalise!: Modal;
  
  private elaboracaoCardapio = Loader.getInstance('Pme00600ElaboracaoCardapio');
  
  public utilities = Loader.getInstance('Utilities');
  
  private custoPadrao: IDictionary = {};
  
  public standardValueSelected = '0,00000';
  
  private datasourceCentral: IDictionary = {};
  
  private datasourceAgregada: IDictionary = {};
  
  public showAnaliseProgress = false;
  
  public showProgessGridCentral = false;
  
  public showProgessGridAgregada = false;
  
  public async createModal() {
    this.modalAnalise = await ModalService.createFromJson('pme/cardapio/modals/pme00611_analise_custo', true);
  }
  
  public fullscreen({ component }: IButtonEvent) {
    this.modalAnalise.fullscreen = !this.modalAnalise.fullscreen;
    component.iconName = (this.modalAnalise.fullscreen) ? 'mdi-fullscreen-exit' : 'mdi-fullscreen';
  }
  
  public cancelModal() {
    if (this.modalAnalise) {
      this.modalAnalise.destroy();
      // this.modalAnalise.hide();
      const cardapio: Cardapio = Metadata.getInstance('cardapio');
      cardapio.setValueAction(false);
    }
  }
  
  public showModal({ event }: IEventParam<Button>) {
    (event as IDictionary).stopPropagation();
    this.validAndOpenModal();
  }
  
  public async validAndOpenModal() {
    if (this.elaboracaoCardapio.getFilterData.NRCARDPME) {
      const cardapio: Cardapio = Metadata.getInstance('cardapio');
      cardapio.setValueAction(true);
      if (this.utilities.checkOpenModalOverlap()) {
        this.createModal().then(() => {
          this.modalAnalise.show();
        });
      }
    } else {
      this.utilities.showAlert('withoutFilter', 'pme::cardapioSemFiltro', 'error');
    }
  }
  
  private changeAnaliseProgress() {
    this.showAnaliseProgress = !this.showAnaliseProgress;
  }
  
  private changeStateProgressCentral() {
    this.showProgessGridCentral = !this.showProgessGridCentral;
  }
  
  private changeStateProgressAgregada() {
    this.showProgessGridAgregada = !this.showProgessGridAgregada;
  }
  
  public analiseProcedureCall() {
    this.changeAnaliseProgress();
    const row = { ...this.elaboracaoCardapio.getFilterData };
    Http.post('/analiseProcedureCall', { requestType: 'Row', row }).then((response) => {
      if (response.data.dataset.consplan.length > 0) {
        this.allRequestAnalise(response.data.dataset.consplan[0]);
      }
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
    });
  }
  
  private allRequestAnalise(consplan: string) {
    this.filterAnaliseCusto(consplan).then((analiseCusto) => {
      this.requestPadrao().then(() => {
        const gridAnalise = Metadata.getInstance<Grid>('analiseGrid');
        this.formatDate(analiseCusto);
        this.calcComenAcu(analiseCusto);
        this.calcTotalPCMedio(analiseCusto);
        gridAnalise.datasource.updateData(analiseCusto).then((data: IDictionary) => {
          this.changeAnaliseProgress();
          gridAnalise.datasource.currentRow = data[0];
          const valueCusto = this.custoPadrao.find(
            (custo: IDictionary) => custo.DTCARDIAPME.substring(0, 10) === data[0].DATAPT.substring(0, 10),
          )?.VRCUSPADTCAR;
          const currencySymbol = this.utilities.getCurrencySymbolLog();
          const valor = (valueCusto)
            ? this.utilities.formatValuesToFixed(valueCusto, 5)
            : this.utilities.formatValuesToFixed(0, 5);
          this.standardValueSelected = `${currencySymbol} ${valor}`;
        });
      });
    });
  }
  
  private filterAnaliseCusto(consplan: string) {
    const cardFilter = this.elaboracaoCardapio.getFilterData;
    const filagre = (cardFilter.aggregated?.CDFILIAL === undefined) ? null : cardFilter.aggregated.CDFILIAL;
    const filial = (cardFilter.aggregated?.CDFILIAL === undefined)
      ? cardFilter.cdfilcentpme : cardFilter.aggregated.CDFILIAL;
    const referenceDate = (cardFilter.referenceDate.length > 0) ? cardFilter.referenceDate : null;
    const exibCost = (cardFilter.baseCost) ? 'S' : 'N';
    
    const filter: IDictionary = [];
    this.utilities.onMountedFilterFind(filter, 'P_NRTIPOCUSTO', '=', cardFilter.planned);
    this.utilities.onMountedFilterFind(filter, 'P_NRCARDPME', '=', cardFilter.NRCARDPME);
    this.utilities.onMountedFilterFind(filter, 'P_CDSERVFILI', '=', cardFilter.service.CDSERVFILI);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIAL', '=', filial);
    this.utilities.onMountedFilterFind(filter, 'P_EXIBCUSTCENT', '=', exibCost);
    this.utilities.onMountedFilterFind(filter, 'P_DTREFECUSTO', '=', referenceDate);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILAGRE', '=', filagre);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILCENTPME', '=', cardFilter.cdfilcentpme);
    this.utilities.onMountedFilterFind(filter, 'P_NRCONSPLAN', '=', consplan);
    this.utilities.onMountedFilterFind(filter, 'P_DTINICIAL', '=', cardFilter.initialDate);
    this.utilities.onMountedFilterFind(filter, 'P_CDTIPOCARD', '=', cardFilter.typeMenu.CDTIPOCARD);
    this.utilities.onMountedFilterFind(filter, 'P_DTFINAL', '=', cardFilter.finalDate);
    this.utilities.onMountedFilterFind(filter, 'P_IDCOMCUSPERC', '=', cardFilter.paramfilial.IDCOMCUSPERC);
    
    return Http.post('/find/analiseCusto', { requestType: 'FilterData', filter, limit: 1000000 }).then((analise) => {
      const analiseCusto = analise.data.data;
      return analiseCusto;
    });
  }
  
  private requestPadrao() {
    const filter: IDictionary = [];
    const filial = (this.elaboracaoCardapio.getFilterData.aggregated?.CDFILIAL === undefined)
      ? this.elaboracaoCardapio.getFilterData.cdfilcentpme
      : this.elaboracaoCardapio.getFilterData.aggregated.CDFILIAL;
    
    this.utilities.onMountedFilterFind(filter, 'P_CDFILCENTPME', '=', this.elaboracaoCardapio.getFilterData.cdfilcentpme);
    this.utilities.onMountedFilterFind(
      filter, 'P_CDSERVFILI', '=', this.elaboracaoCardapio.getFilterData.service.CDSERVFILI,
    );
    this.utilities.onMountedFilterFind(
      filter, 'P_CDTIPOCARD', '=', this.elaboracaoCardapio.getFilterData.typeMenu.CDTIPOCARD,
    );
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIAL', '=', filial);
    this.utilities.onMountedFilterFind(filter, 'P_DTINICIAL', '=', this.elaboracaoCardapio.getFilterData.initialDate);
    this.utilities.onMountedFilterFind(filter, 'P_DTFINAL', '=', this.elaboracaoCardapio.getFilterData.finalDate);
    this.utilities.onMountedFilterFind(filter, 'P_NRCARDPME', '=', this.elaboracaoCardapio.getFilterData.NRCARDPME);
    return Http.post('/find/custoPadraoAcomp', { requestType: 'FilterData', filter, limit: 1000000 }).then((custoPadrao) => {
      this.custoPadrao = custoPadrao.data.data;
    });
  }
  
  public formatDate(analiseCusto: IDictionary) {
    analiseCusto.forEach((custo: IDictionary) => {
      custo.DATAPT = custo.DTDATA;
      custo.DTDATA = moment(custo.DTDATA, 'DD/MM/YYYY').format(this.utilities.getFormatLocaleFullDataWithWeek());
    });
  }
  
  public calcComenAcu(analiseCusto: IDictionary) {
    for (let i = 0; i < analiseCusto.length; i += 1) {
      if (i === 0) {
        analiseCusto[i].VRCOMEACU = analiseCusto[i].QTCOMESTICAR;
      } else {
        analiseCusto[i].VRCUSTOACU += analiseCusto[i - 1].VRCUSTOACU;
        analiseCusto[i].VRCOMEACU = analiseCusto[i].QTCOMESTICAR + analiseCusto[i - 1].VRCOMEACU;
      }
    }
  }
  
  public calcTotalPCMedio(analiseCusto: IDictionary) {
    analiseCusto.forEach((custo: IDictionary) => {
      if (custo.VRCOMEACU === 0) custo.VRCUSTPCMED = 0;
      else custo.VRCUSTPCMED = custo.VRCUSTOACU / custo.VRCOMEACU;
    });
  }
  
  public changeDate({ component }: IButtonEvent) {
    const date = Metadata.getInstance('selectedDate') as Select;
    let momentDate = moment(date.value, 'DD/MM/YYYY');
    if (component.name === 'rightButton') momentDate = moment(date.value, 'DD/MM/YYYY').add(1, 'days');
    else momentDate = moment(date.value, 'DD/MM/YYYY').subtract(1, 'day');
    
    const hasDate = date.datasource.data.find((data: IDictionary) => data.value === momentDate.format('DD/MM/YYYY'));
    if (hasDate !== undefined) date.setValue(momentDate.format('DD/MM/YYYY'));
  }
  
  public filterDataGrid() {
    const date = Metadata.getInstance('selectedDate') as Select;
    this.setStandardValue(date.value);
    
    if (document.getElementsByName('gridPrato')[0] !== undefined) this.mountFilterCentralGrid();
    if (document.getElementsByName('selectAgregada')[0] !== undefined) {
      const gridAgreg = Metadata.getInstance<Select>('selectAgregada');
      this.setFilterAgregOnMount({ component: (gridAgreg as IDictionary) });
    }
  }
  
  public getFilterDates() {
    const datasourceDatas: IDictionary[] = [];
    const date = Metadata.getInstance('selectedDate') as Select;
    const cardapio: Cardapio = Metadata.getInstance('cardapio');
    const gridAnalise = Metadata.getInstance<Grid>('analiseGrid');
    const dateFormat: string | undefined = localStorage.getItem('DATEFORMAT') || undefined;
    const lang = (this.utilities.getLanguage() as string)?.replace('_', '-') || 'pt-br';
    let initialDate = moment(cardapio.filterData.initialDate, 'DD/MM/YYYY').locale(lang);
    const finalDate = moment(cardapio.filterData.finalDate, 'DD/MM/YYYY').locale(lang);

    datasourceDatas.push({ name: initialDate.format(`${dateFormat} ddd`), value: initialDate.format('DD/MM/YYYY') });
    while (this.utilities.isSameOr(initialDate, finalDate, 'before')) {
      initialDate = initialDate.add(1, 'days');
      if (initialDate <= finalDate) {
        datasourceDatas.push(
          {
            name: initialDate.format(`${dateFormat} ddd`),
            value: initialDate.format('DD/MM/YYYY'),
          },
        );
      }
    }
    date.datasource.updateData(datasourceDatas).then(() => {
      const dataDefault = (gridAnalise.datasource.currentRow !== undefined)
        ? gridAnalise.datasource.currentRow.DATAPT.substring(0, 10)
        : date.datasource.data[0].value;
      date.setValue(dataDefault);
    });
  }
  
  public itsBiggerThanPadr({ row }: IDictionary) {
    if (Object.keys(row).length > 0) {
      const data = moment(row.DTDATA.substring(0, 10), this.utilities.getFormatLocale()).format('DD/MM/YYYY');
      const valueCusto = this.custoPadrao.find(
        (custo: IDictionary) => custo.DTCARDIAPME.substring(0, 10) === data,
      )?.VRCUSPADTCAR;
      if (row.VRCUSTPCMED > valueCusto) return 'red';
    }
    
    return '';
  }
  
  public itsBiggerThanPadrTotalPerc({ row }: IDictionary) {
    if (Object.keys(row).length > 0) {
      const data = moment(row.DTDATA.substring(0, 10), this.utilities.getFormatLocale()).format('DD/MM/YYYY');
      const valueCusto = this.custoPadrao.find(
        (custo: IDictionary) => custo.DTCARDIAPME.substring(0, 10) === data,
      )?.VRCUSPADTCAR;
      if (row.VRCUSTTOTALMATPC > valueCusto) return 'red';
    }
    
    return '';
  }
  
  private setStandardValue(dateSelected: string) {
    const valueCusto = this.custoPadrao.find(
      (custo: IDictionary) => custo.DTCARDIAPME.substring(0, 10) === dateSelected,
    )?.VRCUSPADTCAR;
    const currencySymbol = this.utilities.getCurrencySymbolLog();
    const valor = (valueCusto)
      ? this.utilities.formatValuesToFixed(valueCusto, 5)
      : this.utilities.formatValuesToFixed(0, 5);
    this.standardValueSelected = `${currencySymbol} ${valor}`;
  }
  
  // FILTRO TAB MATERIA-PRIMA CENTRAL
  private filterPlates(filial: string) {
    const referenceDate = (this.elaboracaoCardapio.getFilterData.referenceDate.length > 0)
      ? this.elaboracaoCardapio.getFilterData.referenceDate
      : null;
    const filter: IDictionary = [];
    const exibcustcent = (this.elaboracaoCardapio.getFilterData.baseCost) ? 'S' : 'N';
    
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIAL', '=', filial);
    this.utilities.onMountedFilterFind(filter, 'P_EXIBCUSTCENT', '=', exibcustcent);
    this.utilities.onMountedFilterFind(filter, 'P_NRTIPOCUSTO', '=', this.elaboracaoCardapio.getFilterData.planned);
    this.utilities.onMountedFilterFind(filter, 'P_DTREFECUSTO', '=', referenceDate);
    this.utilities.onMountedFilterFind(filter, 'P_NRCARDPME', '=', this.elaboracaoCardapio.getFilterData.NRCARDPME);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILCENTPME', '=', this.elaboracaoCardapio.getFilterData.cdfilcentpme);
    this.utilities.onMountedFilterFind(
      filter, 'P_CDSERVFILI', '=', this.elaboracaoCardapio.getFilterData.service.CDSERVFILI,
    );
    this.utilities.onMountedFilterFind(filter, 'P_DTCARDIAPME', '=', Metadata.getInstance<Select>('selectedDate').value);
    this.utilities.onMountedFilterFind(
      filter, 'P_CDTIPOCARD', '=', this.elaboracaoCardapio.getFilterData.typeMenu.CDTIPOCARD,
    );
    this.utilities.onMountedFilterFind(
      filter, 'P_IDCOMCUSPERC', '=', this.elaboracaoCardapio.getFilterData.paramfilial.IDCOMCUSPERC,
    );
    return Http.post(
      '/find/materiaPrimaCentral',
      { requestType: 'FilterData', filter, limit: 1000000 },
    ).then((matPrimaCentral) => {
      const datasourcePlates = matPrimaCentral.data.data;
      return datasourcePlates;
    });
  }
  
  // Realiza o filtro do grid de Materia Prima - Central
  public mountFilterCentralGrid() {
    this.changeStateProgressCentral();
    this.filterPlates(this.elaboracaoCardapio.getFilterData.cdfilcentpme).then((datasource: IDictionary) => {
      this.datasourceCentral = datasource;
      this.onFilterCentral();
    });
  }
  
  // Monta os dados de acordo com oque veio da query para o grid Materia Prima - Central
  private onFilterCentral() {
    const gridPrato = Metadata.getInstance<Grid>('gridPrato');
    const datasourcePrato: IDictionary[] = [];
    let plates: IDictionary = []; // Array para todos os pratos retornados

    // Pegar todos os cdprato
    this.datasourceCentral.forEach((datasource: IDictionary) => { plates.push(datasource.CDPRATO); });
    plates = this.utilities.removeDuplicateData(plates); // Retira os cdprato repetidos
    
    // Cria um Objeto com apenas os que serão exibidos no grid
    plates.forEach((cdprato: string) => {
      const template: IDictionary = {};
      template.CUSTPRAT = 0; template.CUSTPERCAP = 0; template.SAFRAPORCENT = 0;
      
      const allDataPlate = this.datasourceCentral.filter((data: IDictionary) => data.CDPRATO === cdprato);
      allDataPlate.forEach((allData: IDictionary) => {
        template.CDPRATO = allData.CDPRATO;
        template.NMPRATO = allData.NMPRATO;
        template.CUSTPRAT += (allData.QTTOTAL * allData.CUSTOPROD);
        template.CUSTPERCAP += allData.CUSTOPERCAPITA;
      });
      allDataPlate.forEach((allData: IDictionary) => {
        template.SAFRAPORCENT += this.calcSafrPerc(allData, template);
      });
      
      datasourcePrato.push(template);
    });
    
    const row = datasourcePrato;
    Http.post('/getColorSafPrat', { requestType: 'Row', row }).then((response) => {
      this.mergeColors(datasourcePrato, response.data.dataset.colors);
      gridPrato.datasource.updateData(datasourcePrato).then(() => {
        gridPrato.datasource.currentRow = gridPrato.datasource.data[0];
        this.mountFilterCentralProd({ row: gridPrato.datasource.data[0] });
        this.changeStateProgressCentral();
      });
    });
  }
  
  private mergeColors(datasourcePrato: IDictionary, colors: IDictionary) {
    datasourcePrato.forEach((prato: IDictionary, idx: number) => {
      prato.NRCORSINSAFR = colors[idx];
    });
  }

  public coloredSaf({ row }: IDictionary) {
    if (row.NRCORSINSAFR === null) return '';
    const color = row.NRCORSINSAFR.toString();
    return this.utilities.TColorToHex(color);
  }
  
  private calcSafrPerc(row: IDictionary, template: IDictionary = {}) {
    if (row.IDINTESAFR) {
      const idSaf = this.getIdSafColor(row.IDINTESAFR);
      if (idSaf === '1') return 0;
      
      let custoSaf2 = 0; let custoSaf3 = 0;
      if (idSaf === '2') {
        custoSaf2 = (template.CUSTPERCAP > 0) ? (((row.CUSTOPROD * row.QTDEBRUTA) / template.CUSTPERCAP) * 100) / 2 : 0;
        custoSaf3 = 0;
      } else if (idSaf === '3') {
        custoSaf2 = 0;
        custoSaf3 = (template.CUSTPERCAP > 0) ? ((row.CUSTOPROD * row.QTDEBRUTA) / template.CUSTPERCAP) * 100 : 0;
      }
      
      // if (row.CUSTOPERCAPITA > 0) return ((custoSaf3 / row.CUSTOPERCAPITA) * 100) +
      // ((custoSaf2 / row.CUSTOPERCAPITA) * 100);
      return custoSaf2 + custoSaf3;
    }
    return 0;
  }
  
  public coloredSafProd({ row }: IDictionary) {
    if (row.IDINTESAFR) {
      const color = this.getColoredProd(row.IDINTESAFR);
      return this.utilities.TColorToHex(color);
    }
    return '';
  }
  
  private getIdSafColor(IDINTESAFR: string) {
    const date = Metadata.getInstance<Select>('selectedDate').value;
    const month = parseInt(date.substring(3, 5), 10);
    
    let id = IDINTESAFR.substring(0, month); // Pega a id relacionado aquele mes
    id = id.charAt(id.length - 1);
    
    return id;
  }
  
  private getColoredProd(IDINTESAFR: string) {
    const idSaf = this.getIdSafColor(IDINTESAFR);
    return this.getSafColor(idSaf);
  }
  
  private getSafColor(id: string) {
    let decColor = 0;
    if (id === '1') decColor = this.elaboracaoCardapio.getFilterData.paramplaneja.NRCORSAFRA;
    if (id === '2') decColor = this.elaboracaoCardapio.getFilterData.paramplaneja.NRCORINICSAF;
    if (id === '3') decColor = this.elaboracaoCardapio.getFilterData.paramplaneja.NRCORENTRSAF;
    
    return decColor.toString();
  }

  public changeCurrentPlateCentral() {
    const gridPrato = Metadata.getInstance<Grid>('gridPrato');
    const row = gridPrato.datasource.currentRow as IDictionary;
    this.mountFilterCentralProd({ row });
  }
  
  public mountFilterCentralProd({ row }: IDictionary) {
    if (row !== undefined) {
      let datasource = this.datasourceCentral.filter((data: IDictionary) => data.CDPRATO === row.CDPRATO);
      if (datasource.length === 0) datasource = [];
      
      datasource.forEach((data: IDictionary) => {
        data.PERCAPIT = data.QTDEBRUTA;
      });
      Metadata.getInstance<Grid>('gridCentralProduto').datasource.updateData(datasource);
    } else {
      Metadata.getInstance<Grid>('gridCentralProduto').datasource.updateData([]);
    }
  }
  
  // TAB MATERIA-PRIMA AGREGADA
  public setFilterAgregOnMount({ component }: IDictionary) {
    const filter: IDictionary = [];
    const filial = (this.elaboracaoCardapio.getFilterData.aggregated?.CDFILIAL === undefined)
      ? null
      : this.elaboracaoCardapio.getFilterData.aggregated.CDFILIAL;
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIAL', '=', filial);
    this.utilities.onMountedFilterFind(filter, 'P_NRCARDPME', '=', this.elaboracaoCardapio.getFilterData.NRCARDPME);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILCENTPME', '=', this.elaboracaoCardapio.getFilterData.cdfilcentpme);
    this.utilities.onMountedFilterFind(
      filter, 'P_CDSERVFILI', '=', this.elaboracaoCardapio.getFilterData.service.CDSERVFILI,
    );
    this.utilities.onMountedFilterFind(filter, 'P_DTCARDIAPME', '=', Metadata.getInstance<Select>('selectedDate').value);
    
    component.datasource.filter = filter;
    component.datasource.get().then((data: IDictionary) => {
      const fili = (data.length > 0) ? data[0].CDFILIAL : null;
      component.setValue(fili);
      this.callFilterPlateAgreg();
    });
  }
  
  public callFilterPlateAgreg() {
    const selectAgreg = Metadata.getInstance<Select>('selectAgregada');
    this.changeStateProgressAgregada();
    this.filterPlates(selectAgreg.value).then((datasource: IDictionary) => {
      this.datasourceAgregada = datasource;
      this.onFilterPlateAgreg();
    });
  }
  
  private onFilterPlateAgreg() {
    const datasourcePrato: IDictionary[] = [];
    let plates: IDictionary = []; // Array para todos os pratos retornados
    const gridPrato = Metadata.getInstance<Grid>('gridPratoAgreg');
    
    // Pegar todos os cdprato
    this.datasourceAgregada.forEach(
      (datasource: IDictionary) => { plates.push(datasource.CDPRATO); },
    );
    plates = this.utilities.removeDuplicateData(plates); // Retira os cdprato repetidos
    // Cria um Objeto com apenas os que serão exibidos no grid
    plates.forEach((cdprato: string) => {
      const template: IDictionary = {};
      template.CUSTPRAT = 0; template.CUSTPERCAP = 0; template.SAFRAPORCENT = 0;
      
      const allDataPlate = this.datasourceAgregada.filter((data: IDictionary) => data.CDPRATO === cdprato);
      allDataPlate.forEach((allData: IDictionary) => {
        template.CDPRATO = allData.CDPRATO;
        template.NMPRATO = allData.NMPRATO;
        template.CUSTPRAT += allData.VRTOTAL;
        template.CUSTPERCAP += allData.CUSTOPERCAPITA;
      });
      allDataPlate.forEach((allData: IDictionary) => {
        template.SAFRAPORCENT += this.calcSafrPerc(allData, template);
      });

      datasourcePrato.push(template);
    });
    
    const row = datasourcePrato;
    Http.post('/getColorSafPrat', { requestType: 'Row', row }).then((response) => {
      this.mergeColors(datasourcePrato, response.data.dataset.colors);
      gridPrato.datasource.updateData(datasourcePrato).then((data: IDictionary) => {
        gridPrato.datasource.currentRow = data[0];
        this.mountDataProdAgreg({ row: data[0] });
        this.changeStateProgressAgregada();
      });
    });
  }

  public changeCurrentPlateAgreg() {
    const gridPrato = Metadata.getInstance<Grid>('gridPratoAgreg');
    const row = gridPrato.datasource.currentRow as IDictionary;
    this.mountDataProdAgreg({ row });
  }
  
  public mountDataProdAgreg({ row }: IDictionary) {
    if (row !== undefined) {
      let datasource = this.datasourceAgregada.filter((data: IDictionary) => data.CDPRATO === row.CDPRATO);
      if (datasource.length === 0) datasource = [];
      
      datasource.forEach((data: IDictionary) => {
        data.PERCAPIT = data.QTDEBRUTA;
      });
      Metadata.getInstance<Grid>('gridAgregadaProduto').datasource.updateData(datasource);
    } else {
      Metadata.getInstance<Grid>('gridAgregadaProduto').datasource.updateData([]);
    }
  }
  
  public setDateOnRawMaterial({ row }: IDictionary) {
    const valueCusto = this.custoPadrao.find(
      (custo: IDictionary) => custo.DTCARDIAPME.substring(0, 10) === row.DATAPT.substring(0, 10),
    )?.VRCUSPADTCAR;
    const currencySymbol = this.utilities.getCurrencySymbolLog();
    const valor = (valueCusto)
      ? this.utilities.formatValuesToFixed(valueCusto, 5)
      : this.utilities.formatValuesToFixed(0, 5);
    this.standardValueSelected = `${currencySymbol} ${valor}`;
    
    if (document.getElementsByName('selectedDate')[0]) {
      const date = Metadata.getInstance('selectedDate') as Select;
      date.setValue(row.DATAPT.substring(0, 10));
    }
  }
  
  public filterDataGridMateriaPrima({ component }: IDictionary) {
    if (component.activeTab === 1) this.filterDataGrid();
  }
}
